.. pypipegraph documentation master file, created by
   sphinx-quickstart on Mon Jan 30 14:03:54 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pypipegraph's documentation!
=======================================

This document describes the current pipegraph api as you'd use it.
Please see http://github.com/TyberiusPrime/pypipegraph for the project's homepage.

.. toctree::
   :maxdepth: 2

   tutorial
   jobs
   api


Development notes
-------------------

 *  We use pytest for testing.

